#!/usr/bin/env python

from Engineering_tools import *

import unittest

"""
    This is a prototype of test bench for Engineering_tools functions
    Each function can be tested using a set of specific parameters.
    The results can be evaluated and the success of test is defined by asser**** 
    function call.
"""
class TestEngineeringTools(unittest.TestCase):


    
   def test_initial_vel(self):        
      latitude = 30
      v_velocity = initial_vel(latitude)
      self.assertTrue(v_velocity is not None)
      
   
   def test_final_target_vel(self):        
      v_eject_altitude = 100000
      v_orbit_semi_major_axis = 637800000
      
      v_f_velocity = final_target_vel(v_eject_altitude,v_orbit_semi_major_axis)
      
      self.assertTrue(v_f_velocity is not None)
     

   def test_staging_optim(self):
      v_isp1 = 300
      v_isp2 = 300
      v_eps1 = 0.8
      v_eps2 = 0.7
      v_Vc = 100
      v_Mp = 3000
      v_m1, v_m2 = staging_optim(v_isp1,v_isp2,v_eps1,v_eps2,v_Vc,v_Mp)
      self.assertTrue(v_m1 is not None and v_m2 is not None)

   def test_rocket_engine_modelling(self):
      gamma = 1.4
      R = 8.314
     
      sol = 0

      Pcc = 200e5
      Pa = 1e5
      Tin = 273.15
      
      Ae = 0.5
      Ath = 0.007
      dth = np.sqrt((4*Ath)/np.pi)
      print('dth: ', dth)
      epsilon = 1e-4

      Mcc, Tcc, Acc, M = combustion_chamber(dth, gamma, Tin, Pcc, epsilon, sol)  
      print('Acc, Ath: ',Acc,Ath)
      r = R/M
      Th, isp, Me, Pe, Te = laval_nozzle(Pcc,Tcc,Pa,Ath,Ae,gamma,r)
      print('========== Combustion Chamber ==========','\n')
      print(' *Nombre de Mach:',Mcc,'\n')
      print(' *Temperature:',Tcc,'K\n')
      print(' *Section:',Acc,'m²','\n')
      print('========== Laval Nozzle ==========','\n')
      print(' *Pression de Sortie:',Pe,'Pa\n')
      print(' *Temperature de Sortie:',Te,'K\n')  
      print(' *Nombre de Mach:',Me,'\n')
      print(' *Pousee:',Th*1e-6,'MN','\n')
      print(' *Isp:',isp,'s','\n')

      self.assertTrue(Th is not None and isp is not None)


if __name__ == '__main__':      
   unittest.main()
